@@ -3,42 +3,47 @@
 
 #include "about.h"
 #include "help.h"
-#include "wresistors.h"
-#include "ohmsa.h"
-#include "power.h"
+#include "resistors.h"
+#include "calculations.h"
+#include "caps.h"
 
 #include <QtCore/QCoreApplication>
 #include <QDesktopServices>
 #include <QUrl>
+#include <QShortcut>
 
 MainWindow::MainWindow(QWidget *parent):
     QMainWindow(parent),
     ui(new Ui::MainWindow),
       about(0),
       help(0),
-      wresistors(0),
-      ohmsa(0),
-      power(0)
-
+      caps(0),
+      resistors(0),
+      calculations(0)
 {
     ui->setupUi(this);
 
+    //Window Text
+    this->setWindowTitle("Bander");
     setAttribute(Qt::WA_Maemo5StackedWindow);
+
     about = new About(this);
     help = new Help(this);
-    wresistors = new wResistors(this);
-    ohmsa = new Ohmsa(this);
-    power = new Power(this);
+    caps = new Caps(this);
+    resistors = new Resistors(this);
+    calculations = new Calculations(this);
 
+    // For Connecting Keyboard Buttons
+    connectSignals();
 }
 
 MainWindow::~MainWindow()
 {
     if (about) delete (about);
     if (help) delete (help);
-    if (wresistors) delete (wresistors);
-    if (ohmsa) delete (ohmsa);
-    if (power) delete (power);
+    if (caps) delete (caps);
+    if (resistors) delete (resistors);
+    if (calculations) delete (calculations);
     delete ui;
 }
 
@@ -96,6 +101,20 @@ void MainWindow::showExpanded()
 #endif
 }
 
+// Keyboard Button Signals - remember to include QShortcut
+void MainWindow::connectSignals()
+{
+
+// Keyboard Key Signals
+  connect(new QShortcut(QKeySequence(Qt::Key_Q), this), SIGNAL(activated()), this, SLOT(on_pushButtonColors_clicked()));
+  connect(new QShortcut(QKeySequence(Qt::Key_W), this), SIGNAL(activated()), this, SLOT(on_pushButtonCalculations_clicked()));
+  connect(new QShortcut(QKeySequence(Qt::Key_E), this), SIGNAL(activated()), this, SLOT(on_pushButtonCaps_clicked()));
+}
+
+// End of Keyboard Signals
+
+//Menu
+
 void MainWindow::on_actionAbout_triggered()
 {
     about->show();
@@ -106,17 +125,17 @@ void MainWindow::on_actionHelp_triggered()
     help->show();
 }
 
-void MainWindow::on_pushButtonResistor_clicked()
+void MainWindow::on_pushButtonCalculations_clicked()
 {
-    wresistors->show();
+    calculations->show();
 }
 
-void MainWindow::on_pushButtonOhmsa_clicked()
+void MainWindow::on_pushButtonCaps_clicked()
 {
-    ohmsa->show();
+    caps->show();
 }
 
-void MainWindow::on_pushButtonPower_clicked()
+void MainWindow::on_pushButtonColors_clicked()
 {
-    power->show();
+    resistors->show();
 }
