@@ -5,9 +5,9 @@
 
 class About;
 class Help;
-class wResistors;
-class Ohmsa;
-class Power;
+class Caps;
+class Resistors;
+class Calculations;
 
 namespace Ui {
     class MainWindow;
@@ -34,24 +34,27 @@ public:
 
 private slots:
 
+    // For Connecting Keyboard buttons
+    void connectSignals();
+
+    //Slots
     void on_actionAbout_triggered();
 
     void on_actionHelp_triggered();
 
-    void on_pushButtonResistor_clicked();
+    void on_pushButtonCalculations_clicked();
 
-    void on_pushButtonOhmsa_clicked();
+    void on_pushButtonCaps_clicked();
 
-    void on_pushButtonPower_clicked();
+    void on_pushButtonColors_clicked();
 
 private:
     Ui::MainWindow *ui;
     About *about;
     Help *help;
-    wResistors *wresistors;
-    Ohmsa *ohmsa;
-    Power *power;
-
+    Caps *caps;
+    Resistors *resistors;
+    Calculations *calculations;
 };
 
 #endif // MAINWINDOW_H
